A Defesa alegou, ainda, ser “esdrúxula afirmação de que se trata de área de especial preservação vem da própria lei”. 
Não é, no entanto, o entendimento do E. TRIBUNAL DE JUSTIÇA DO ESTADO DE MATO GROSSO:

“(...) O Município de Vila Bela da Santíssima Trindade compõe a denominada Amazônia Legal, que mereceu do Poder Constituinte Originário especial distinção, ao dispor no artigo 225, § 4º, da Constituição da Republica Federativa do Brasil: “A Floresta Amazônica brasileira, a Mata Atlântica, a Serra do Mar, o Pantanal Mato-Grossense e a Zona Costeira são patrimônio nacional, e sua utilização far-se-á, na forma da lei, dentro de condições que assegurem a preservação do meio ambiente, inclusive quanto ao uso dos recursos naturais.” (TJ-MT - AI: 10041722920168110000 MT, Relator: LUIZ CARLOS DA COSTA, Data de Julgamento: 19/01/2017, Segunda Câmara de Direito Público e Coletivo, Data de Publicação: 23/01/2017)

Também já se pronunciaram nesse sentido o Supremo Tribunal Federal e diversos tribunais pátrios:

“(...) Embora não desprezíveis as alegações da inicial, concernentes a possível violação do direito de propriedade, sem prévia e justa indenização, é de se objetar, por outro lado, que a Constituição deu tratamento especial à Floresta Amazônica, ao integrá-la no patrimônio nacional, aduzindo que sua utilização se fará, na forma da lei, dentro de condições que assegurem a preservação do meio ambiente, inclusive quanto ao uso dos recursos naturais. (...) (STF, Tribunal Pleno, ADI 1516/UF MC, relator Ministro Sydney Sanches, publicado no Diário da Justiça em 13 de agosto de 1999).

CRIME CONTRA A FLORA. TRANSPORTE DE MADEIRA DA MATA ATL NTICA. ART. 225, PAR.4º, DA CONSTITUIÇÃO FEDERAL. INTERESSE NACIONAL.COMPETÊNCIA DA JUSTIÇA FEDERAL. 1. Por força da técnica de repartição de competências, adotadas pelo constituinte de 1988, o interesse nacional é matéria de competência da União. Aplicação do princípio da predominância do interesse, que recomenda a permanência de assuntos de interesse nacional na esfera Federal. 2. Evidenciado o interesse da União na preservação do patrimônio nacional, descrito no art. 225, parágrafo 4º, da Constituição, é competente a Justiça Federal para julgar delitos que afetem as áreas naturais nele mencionadas, entre estas a Mata Atlântica. 3. Recurso provido. (TRF-4 - RSE: 115572 SC 1999.04.01.115572-0, Relator: FERNANDO QUADROS DA SILVA, Data de Julgamento: 27/04/2000, SEGUNDA TURMA, Data de Publicação: DJ 14/06/2000 PÁGINA: 112)

ADMINISTRATIVO E PROCESSUAL CIVIL. INSTITUTO BRASILEIRO DO MEIO AMBIENTE E DOS RECURSOS NATURAIS RENOVÁVIES (IBAMA). AUTO DE INFRAÇÃO. DESTRUIÇÃO DE VEGETAÇÃO NATIVA, TIPO FLORESTA AMAZÔNICA, OBJETO DE ESPECIAL PRESERVAÇÃO, SEM AUTORIZAÇÃO DA AUTORIDADE AMBIENTAL COMPETENTE. COMPETÊNCIA DO IBAMA. AUTORIZAÇÃO PROVISÓRIA DE FUNCIONAMENTO DE ATIVIDADE RURAL (APF) E CADASTRO AMBIENTAL RURAL (CAR). NATUREZA AUTODECLARATÓRIA. PROVA INEQUÍVOCA DA REGULARIDADE DA ATIVIDADE. INEXISTÊNCIA. AGRAVO DE INSTRUMENTO. DESPROVIMENTO. AGRAVO INTERNO PREJUDICADO. 1. Nos termos do art. 17, § 3º, da Lei Complementar n. 140/2011, o Ibama tem competência para lavrar o auto de infração de que tratam os autos, diante da constatação da destruição de vegetação nativa sem autorização da autoridade ambiental competente e da omissão do autoridade ambiental estadual. 2. A Autorização Provisória de Funcionamento de Atividade Rural (APF), bem como o Cadastro Ambiental Rural (CAR), dada a natureza autodeclaratória, não tem condão, por si só, de comprovar a regularidade do desmate na área embargada, de modo a afastar a presunção de veracidade da autuação do Ibama, mormente considerando que, no caso, a APF somente foi emitida depois da autuação do órgão ambiental. 3. "A derrubada de espécies nativas da Floresta Amazônica configura ofensa aos interesses da União e ao patrimônio nacional e da humanidade, o que, por si só, justificaria a medida preventiva de suspensão de eventuais atividades agrícolas ou pecuárias desenvolvidas pelo agravado enquanto se examina a questão" (TRF da 1ª Região: AG n. 0030003-16.2013.4.01.0000/MT - Relator Desembargador Federal Jirair Aram Meguerian - e-DJF1 de 18.12.2015) 4. Agravo de Instrumento desprovido. Agravo interno prejudicado. (TRF-1 - AI: 00734115220164010000 0073411-52.2016.4.01.0000, Relator: DESEMBARGADOR FEDERAL DANIEL PAES RIBEIRO, Data de Julgamento: 16/10/2017, SEXTA TURMA, Data de Publicação: 24/10/2017 e-DJF1)
Ora, a proteção conferida à Floresta Amazônica e à Mata Atlântica é a mesma que se concede ao Pantanal Mato-grossense e tem sede constitucional:
Art. 225. Todos têm direito ao meio ambiente ecologicamente equilibrado, bem de uso comum do povo e essencial à sadia qualidade de vida, impondo-se ao Poder Público e à coletividade o dever de defendê-lo e preservá- lo para as presentes e futuras gerações. (...)
§ 4º A Floresta Amazônica brasileira, a Mata Atlântica, a Serra do Mar, o Pantanal Mato-Grossense e a Zona Costeira são patrimônio nacional, e sua utilização far-se-á, na forma da lei, dentro de condições que assegurem a preservação do meio ambiente, inclusive quanto ao uso dos recursos naturais.
